Lock toggle
============

.. automodule:: drain_swamp.lock_toggle
   :members:
   :undoc-members:
   :exclude-members: in_files
   :platform: Unix
   :synopsis: lock and unlock package dependencies
   :ignore-module-all:
